@@ -6,11 +6,13 @@ class OdaPATHS:
 
     project = Path(__file__).resolve().parent.parent
     scripts = project / "oda_data"
-    raw_data = scripts / "raw_data"
+    raw_data = scripts / ".raw_data"
     pydeflate = raw_data / ".pydeflate"
     indicators = scripts / "indicators"
     cleaning_config = scripts / "clean_data"
     sectors = indicators / "sectors"
+    tests = project / "tests"
+    test_files = tests / "files"
 
 
 # ------------------------------ Key URLs ------------------------------ #
@@ -21,3 +23,5 @@ CRS_URL: str = f"{BASE_URL}CRS1"
 TABLE1_URL: str = f"{BASE_URL}TABLE1"
 TABLE2A_URL: str = f"{BASE_URL}TABLE2A"
 MULTISYSTEM_URL: str = f"{BASE_URL}MULTISYSTEM"
+
+CODES_URL: str = "https://webfs.oecd.org/crs-iati-xml/Lookup/DAC-CRS-CODES.xml"
